pub fn gdt_init(tss: &'static Tss) -> (GlobalDescriptorTable, GdtSetupInfo)Expand description
Build the GDT and return it and a struct containing it and all its segment selectors
pub fn gdt_init(tss: &'static Tss) -> (GlobalDescriptorTable, GdtSetupInfo)Build the GDT and return it and a struct containing it and all its segment selectors