gdt_load

Function gdt_load 

pub unsafe fn gdt_load(
    gdt: &'static GlobalDescriptorTable,
    gdt_setup_info: &GdtSetupInfo,
)
Load the GDT and its selectors

Safety

The caller must guarantee that the given segment selectors in gdt_setup_info are valid and point to the given gdt