Struct GdtSetupInfo
Source pub struct GdtSetupInfo {
pub kernel_code: SegmentSelector,
pub kernel_data: SegmentSelector,
pub user_code: SegmentSelector,
pub user_data: SegmentSelector,
pub tss_selector: SegmentSelector,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.